littlemcmc.NUTS
===============

.. currentmodule:: littlemcmc

.. autoclass:: NUTS

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NUTS.__init__
      ~NUTS.reset
      ~NUTS.reset_tuning
      ~NUTS.stop_tuning
      ~NUTS.warnings
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NUTS.default_blocked
      ~NUTS.generates_stats
      ~NUTS.name
      ~NUTS.stats_dtypes
   
   